gnunet-svn
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[taler-wallet-core] branch master updated: refresh history


From: gnunet
Subject: [taler-wallet-core] branch master updated: refresh history
Date: Fri, 13 Dec 2019 13:36:38 +0100

This is an automated email from the git hooks/post-receive script.

dold pushed a commit to branch master
in repository wallet-core.

The following commit(s) were added to refs/heads/master by this push:
     new e018e073 refresh history
e018e073 is described below

commit e018e073a4666c9521c0a802caa704d5ae5089b7
Author: Florian Dold <address@hidden>
AuthorDate: Fri Dec 13 13:36:35 2019 +0100

    refresh history
---
 src/types/history.ts | 11 +++++++----
 1 file changed, 7 insertions(+), 4 deletions(-)

diff --git a/src/types/history.ts b/src/types/history.ts
index 08c49987..06b86300 100644
--- a/src/types/history.ts
+++ b/src/types/history.ts
@@ -611,10 +611,12 @@ export const enum RefreshReason {
   Pay = "pay",
   Refund = "refund",
   AbortPay = "abort-pay",
+  Recoup = "recoup",
+  BackupRestored = "backup-restored",
 }
 
 /**
  * Event to indicate that a refresh operation completed.
  */
 export interface HistoryRefreshedEvent {
   /**
@@ -629,14 +631,15 @@ export interface HistoryRefreshedEvent {
   amountRefreshed: string;
 
   /**
-   * Why was the refresh done?
+   * Why was the refreshing done?
    */
   refreshReason: RefreshReason;
 
   /**
-   * Refresh session ID, to find out more details.
+   * Identifier for a refresh group, contains one or
+   * more refresh session IDs.
    */
-  refreshSessionId: string;
+  refreshGroupId: string;
 }
 
 /**
@@ -611,10 +611,12 @@ export const enum RefreshReason {
 
 /**
- * Event to indicate that a refresh operation completed.
+ * Event to indicate that a group of refresh sessions has completed.
  */
 export interface HistoryRefreshedEvent {

-- 
To stop receiving notification emails like this one, please contact
address@hidden.



reply via email to

[Prev in Thread] Current Thread [Next in Thread]